@@ -32,6 +32,8 @@ from openstackclient.identity import common
 
 DEFAULT_CONTAINER_FORMAT = 'bare'
 DEFAULT_DISK_FORMAT = 'raw'
+DISK_CHOICES = ["ami", "ari", "aki", "vhd", "vmdk", "raw", "qcow2", "vhdx",
+                "vdi", "iso", "ploop"]
 
 
 LOG = logging.getLogger(__name__)
@@ -140,9 +142,10 @@ class CreateImage(command.ShowOne):
         parser.add_argument(
             "--disk-format",
             default=DEFAULT_DISK_FORMAT,
+            choices=DISK_CHOICES,
             metavar="<disk-format>",
-            help=_("Image disk format "
-                   "(default: %s)") % DEFAULT_DISK_FORMAT,
+            help=_("Image disk format. The supported options are: %s. "
+                   "The default format is: raw") % ', '.join(DISK_CHOICES)
         )
         parser.add_argument(
             "--min-disk",
@@ -447,8 +450,9 @@ class ListImage(command.Lister):
         parser.add_argument(
             '--sort',
             metavar="<key>[:<direction>]",
+            default='name:asc',
             help=_("Sort output by selected keys and directions(asc or desc) "
-                   "(default: asc), multiple keys and directions can be "
+                   "(default: name:asc), multiple keys and directions can be "
                    "specified separated by comma"),
         )
         parser.add_argument(
@@ -482,7 +486,6 @@ class ListImage(command.Lister):
         if parsed_args.marker:
             kwargs['marker'] = utils.find_resource(image_client.images,
                                                    parsed_args.marker).id
-
         if parsed_args.long:
             columns = (
                 'ID',
@@ -515,7 +518,19 @@ class ListImage(command.Lister):
             column_headers = columns
 
         # List of image data received
-        data = image_client.api.image_list(**kwargs)
+        data = []
+        if 'marker' in kwargs:
+            data = image_client.api.image_list(**kwargs)
+        else:
+            # No pages received yet, so start the page marker at None.
+            marker = None
+            while True:
+                page = image_client.api.image_list(marker=marker, **kwargs)
+                if not page:
+                    break
+                data.extend(page)
+                # Set the marker to the id of the last item we received
+                marker = page[-1]['id']
 
         if parsed_args.property:
             # NOTE(dtroyer): coerce to a list to subscript it in py3
@@ -650,8 +665,9 @@ class SetImage(command.Command):
         parser.add_argument(
             "--disk-format",
             metavar="<disk-format>",
-            help=_("Image disk format "
-                   "(default: %s)") % DEFAULT_DISK_FORMAT,
+            choices=DISK_CHOICES,
+            help=_("Image disk format. The supported options are: %s") %
+            ', '.join(DISK_CHOICES)
         )
         protected_group = parser.add_mutually_exclusive_group()
         protected_group.add_argument(
