@@ -18,7 +18,7 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
-
+from openstackclient.network import sdk_utils
 
 _formatters = {
     'subnet_ip_availability': utils.format_list_of_dicts,
@@ -26,15 +26,16 @@ _formatters = {
 
 
 def _get_columns(item):
-    columns = list(item.keys())
-    if 'tenant_id' in columns:
-        columns.remove('tenant_id')
-        columns.append('project_id')
-    return tuple(sorted(columns))
+    column_map = {
+        'tenant_id': 'project_id',
+    }
+    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
+# TODO(ankur-gupta-f): Use the SDK resource mapped attribute names once
+# the OSC minimum requirements include SDK 1.0.
 class ListIPAvailability(command.Lister):
-    """List IP availability for network"""
+    _description = _("List IP availability for network")
 
     def get_parser(self, prog_name):
         parser = super(ListIPAvailability, self).get_parser(prog_name)
@@ -84,6 +85,7 @@ class ListIPAvailability(command.Lister):
                 parsed_args.project_domain,
             ).id
             filters['tenant_id'] = project_id
+            filters['project_id'] = project_id
         data = client.network_ip_availabilities(**filters)
         return (column_headers,
                 (utils.get_item_properties(
@@ -92,7 +94,7 @@ class ListIPAvailability(command.Lister):
 
 
 class ShowIPAvailability(command.ShowOne):
-    """Show network IP availability details"""
+    _description = _("Show network IP availability details")
 
     def get_parser(self, prog_name):
         parser = super(ShowIPAvailability, self).get_parser(prog_name)
@@ -107,6 +109,6 @@ class ShowIPAvailability(command.ShowOne):
         client = self.app.client_manager.network
         obj = client.find_network_ip_availability(parsed_args.network,
                                                   ignore_missing=False)
-        columns = _get_columns(obj)
+        display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
-        return (columns, data)
+        return (display_columns, data)
