@@ -25,6 +25,7 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
+from openstackclient.network import sdk_utils
 
 
 LOG = logging.getLogger(__name__)
@@ -51,6 +52,7 @@ def _format_routes(routes):
 
 _formatters = {
     'admin_state_up': _format_admin_state,
+    'is_admin_state_up': _format_admin_state,
     'external_gateway_info': _format_external_gateway_info,
     'availability_zones': utils.format_list,
     'availability_zone_hints': utils.format_list,
@@ -59,11 +61,13 @@ _formatters = {
 
 
 def _get_columns(item):
-    columns = list(item.keys())
-    if 'tenant_id' in columns:
-        columns.remove('tenant_id')
-        columns.append('project_id')
-    return tuple(sorted(columns))
+    column_map = {
+        'tenant_id': 'project_id',
+        'is_ha': 'ha',
+        'is_distributed': 'distributed',
+        'is_admin_state_up': 'admin_state_up',
+    }
+    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 def _get_attrs(client_manager, parsed_args):
@@ -150,6 +154,8 @@ class AddSubnetToRouter(command.Command):
             subnet_id=subnet.id)
 
 
+# TODO(yanxing'an): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class CreateRouter(command.ShowOne):
     _description = _("Create a new router")
 
@@ -215,10 +221,10 @@ class CreateRouter(command.ShowOne):
             attrs['ha'] = parsed_args.ha
         obj = client.create_router(**attrs)
 
-        columns = _get_columns(obj)
+        display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
-        return (columns, data)
+        return (display_columns, data)
 
 
 class DeleteRouter(command.Command):
@@ -255,6 +261,8 @@ class DeleteRouter(command.Command):
             raise exceptions.CommandError(msg)
 
 
+# TODO(yanxing'an): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class ListRouter(command.Lister):
     _description = _("List routers")
 
@@ -282,19 +290,25 @@ class ListRouter(command.Lister):
             default=False,
             help=_("List additional fields in output")
         )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_("List routers according to their project (name or ID)")
+        )
+        identity_common.add_project_domain_option_to_parser(parser)
         return parser
 
     def take_action(self, parsed_args):
+        identity_client = self.app.client_manager.identity
         client = self.app.client_manager.network
-
         columns = (
             'id',
             'name',
             'status',
-            'admin_state_up',
-            'distributed',
-            'ha',
-            'tenant_id',
+            'is_admin_state_up',
+            'is_distributed',
+            'is_ha',
+            'project_id',
         )
         column_headers = (
             'ID',
@@ -313,9 +327,19 @@ class ListRouter(command.Lister):
 
         if parsed_args.enable:
             args['admin_state_up'] = True
+            args['is_admin_state_up'] = True
         elif parsed_args.disable:
             args['admin_state_up'] = False
+            args['is_admin_state_up'] = False
 
+        if parsed_args.project:
+            project_id = identity_common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+            args['tenant_id'] = project_id
+            args['project_id'] = project_id
         if parsed_args.long:
             columns = columns + (
                 'routes',
@@ -394,6 +418,8 @@ class RemoveSubnetFromRouter(command.Command):
             subnet_id=subnet.id)
 
 
+# TODO(yanxing'an): Use the SDK resource mapped attribute names once the
+# OSC minimum requirements include SDK 1.0.
 class SetRouter(command.Command):
     _description = _("Set router properties")
 
@@ -473,9 +499,32 @@ class SetRouter(command.Command):
             help=_("Clear high availablability attribute of the router "
                    "(disabled router only)")
         )
-        # TODO(tangchen): Support setting 'external_gateway_info' property in
-        # 'router set' command.
-
+        parser.add_argument(
+            '--external-gateway',
+            metavar="<network>",
+            help=_("External Network used as router's gateway (name or ID)")
+        )
+        parser.add_argument(
+            '--fixed-ip',
+            metavar='subnet=<subnet>,ip-address=<ip-address>',
+            action=parseractions.MultiKeyValueAction,
+            optional_keys=['subnet', 'ip-address'],
+            help=_("Desired IP and/or subnet (name or ID)"
+                   "on external gateway: "
+                   "subnet=<subnet>,ip-address=<ip-address> "
+                   "(repeat option to set multiple fixed IP addresses)")
+        )
+        snat_group = parser.add_mutually_exclusive_group()
+        snat_group.add_argument(
+            '--enable-snat',
+            action='store_true',
+            help=_("Enable Source NAT on external gateway")
+        )
+        snat_group.add_argument(
+            '--disable-snat',
+            action='store_true',
+            help=_("Disable Source NAT on external gateway")
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -504,7 +553,34 @@ class SetRouter(command.Command):
             for route in parsed_args.routes:
                 route['nexthop'] = route.pop('gateway')
             attrs['routes'] = obj.routes + parsed_args.routes
-
+        if (parsed_args.disable_snat or parsed_args.enable_snat or
+           parsed_args.fixed_ip) and not parsed_args.external_gateway:
+                msg = (_("You must specify '--external-gateway' in order"
+                         "to update the SNAT or fixed-ip values"))
+                raise exceptions.CommandError(msg)
+        if parsed_args.external_gateway:
+            gateway_info = {}
+            network = client.find_network(
+                parsed_args.external_gateway, ignore_missing=False)
+            gateway_info['network_id'] = network.id
+            if parsed_args.disable_snat:
+                gateway_info['enable_snat'] = False
+            if parsed_args.enable_snat:
+                gateway_info['enable_snat'] = True
+            if parsed_args.fixed_ip:
+                ips = []
+                for ip_spec in parsed_args.fixed_ip:
+                    if ip_spec.get('subnet', False):
+                        subnet_name_id = ip_spec.pop('subnet')
+                        if subnet_name_id:
+                            subnet = client.find_subnet(subnet_name_id,
+                                                        ignore_missing=False)
+                            ip_spec['subnet_id'] = subnet.id
+                    if ip_spec.get('ip-address', False):
+                        ip_spec['ip_address'] = ip_spec.pop('ip-address')
+                    ips.append(ip_spec)
+                gateway_info['external_fixed_ips'] = ips
+            attrs['external_gateway_info'] = gateway_info
         client.update_router(obj, **attrs)
 
 
@@ -523,9 +599,10 @@ class ShowRouter(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         obj = client.find_router(parsed_args.router, ignore_missing=False)
-        columns = _get_columns(obj)
+        display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
-        return (columns, data)
+
+        return (display_columns, data)
 
 
 class UnsetRouter(command.Command):
@@ -544,6 +621,11 @@ class UnsetRouter(command.Command):
                    "destination: destination subnet (in CIDR notation) "
                    "gateway: nexthop IP address "
                    "(repeat option to unset multiple routes)"))
+        parser.add_argument(
+            '--external-gateway',
+            action='store_true',
+            default=False,
+            help=_("Remove external gateway information from the router"))
         parser.add_argument(
             'router',
             metavar="<router>",
@@ -565,5 +647,7 @@ class UnsetRouter(command.Command):
                 msg = (_("Router does not contain route %s") % route)
                 raise exceptions.CommandError(msg)
             attrs['routes'] = tmp_routes
+        if parsed_args.external_gateway:
+            attrs['external_gateway_info'] = {}
         if attrs:
             client.update_router(obj, **attrs)
