@@ -81,8 +81,9 @@ def _get_columns(item):
         columns.remove('security_group_rules')
         property_column_mappings.append(('rules', 'security_group_rules'))
     if 'tenant_id' in columns:
-        columns.append('project_id')
         columns.remove('tenant_id')
+        if 'project_id' not in columns:
+            columns.append('project_id')
         property_column_mappings.append(('project_id', 'tenant_id'))
     display_columns = sorted(columns)
 
@@ -201,6 +202,13 @@ class ListSecurityGroup(common.NetworkAndComputeLister):
             default=False,
             help=argparse.SUPPRESS,
         )
+        parser.add_argument(
+            '--project',
+            metavar='<project>',
+            help=_("List security groups according to the project "
+                   "(name or ID)")
+        )
+        identity_common.add_project_domain_option_to_parser(parser)
         return parser
 
     def update_parser_compute(self, parser):
@@ -228,7 +236,16 @@ class ListSecurityGroup(common.NetworkAndComputeLister):
                 ) for s in data))
 
     def take_action_network(self, client, parsed_args):
-        return self._get_return_data(client.security_groups())
+        filters = {}
+        if parsed_args.project:
+            identity_client = self.app.client_manager.identity
+            project_id = identity_common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+            filters['tenant_id'] = project_id
+        return self._get_return_data(client.security_groups(**filters))
 
     def take_action_compute(self, client, parsed_args):
         search = {'all_tenants': parsed_args.all_projects}
