@@ -18,6 +18,7 @@ from osc_lib import exceptions
 
 from openstackclient.network.v2 import floating_ip
 from openstackclient.tests.unit.compute.v2 import fakes as compute_fakes
+from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes_v3
 from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
@@ -31,6 +32,10 @@ class TestFloatingIPNetwork(network_fakes.TestNetworkV2):
 
         # Get a shortcut to the network client
         self.network = self.app.client_manager.network
+        # Get a shortcut to the ProjectManager Mock
+        self.projects_mock = self.app.client_manager.identity.projects
+        # Get a shortcut to the DomainManager Mock
+        self.domains_mock = self.app.client_manager.identity.domains
 
 
 class TestCreateFloatingIPNetwork(TestFloatingIPNetwork):
@@ -145,6 +150,54 @@ class TestCreateFloatingIPNetwork(TestFloatingIPNetwork):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
+    def test_floating_ip_create_project(self):
+        project = identity_fakes_v3.FakeProject.create_one_project()
+        self.projects_mock.get.return_value = project
+        arglist = [
+            '--project', project.id,
+            self.floating_ip.floating_network_id,
+        ]
+        verifylist = [
+            ('network', self.floating_ip.floating_network_id),
+            ('project', project.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_ip.assert_called_once_with(**{
+            'floating_network_id': self.floating_ip.floating_network_id,
+            'tenant_id': project.id,
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_floating_ip_create_project_domain(self):
+        project = identity_fakes_v3.FakeProject.create_one_project()
+        domain = identity_fakes_v3.FakeDomain.create_one_domain()
+        self.projects_mock.get.return_value = project
+        arglist = [
+            "--project", project.name,
+            "--project-domain", domain.name,
+            self.floating_ip.floating_network_id,
+        ]
+        verifylist = [
+            ('network', self.floating_ip.floating_network_id),
+            ('project', project.name),
+            ('project_domain', domain.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_ip.assert_called_once_with(**{
+            'floating_network_id': self.floating_ip.floating_network_id,
+            'tenant_id': project.id,
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
 
 class TestDeleteFloatingIPNetwork(TestFloatingIPNetwork):
 
@@ -231,6 +284,15 @@ class TestListFloatingIPNetwork(TestFloatingIPNetwork):
 
     # The floating ips to list up
     floating_ips = network_fakes.FakeFloatingIP.create_floating_ips(count=3)
+    fake_network = network_fakes.FakeNetwork.create_one_network({
+        'id': 'fake_network_id',
+    })
+    fake_port = network_fakes.FakePort.create_one_port({
+        'id': 'fake_port_id',
+    })
+    fake_router = network_fakes.FakeRouter.create_one_router({
+        'id': 'fake_router_id',
+    })
 
     columns = (
         'ID',
@@ -240,8 +302,14 @@ class TestListFloatingIPNetwork(TestFloatingIPNetwork):
         'Floating Network',
         'Project',
     )
+    columns_long = columns + (
+        'Router',
+        'Status',
+        'Description',
+    )
 
     data = []
+    data_long = []
     for ip in floating_ips:
         data.append((
             ip.id,
@@ -251,11 +319,25 @@ class TestListFloatingIPNetwork(TestFloatingIPNetwork):
             ip.floating_network_id,
             ip.tenant_id,
         ))
+        data_long.append((
+            ip.id,
+            ip.floating_ip_address,
+            ip.fixed_ip_address,
+            ip.port_id,
+            ip.floating_network_id,
+            ip.tenant_id,
+            ip.router_id,
+            ip.status,
+            ip.description,
+        ))
 
     def setUp(self):
         super(TestListFloatingIPNetwork, self).setUp()
 
         self.network.ips = mock.Mock(return_value=self.floating_ips)
+        self.network.find_network = mock.Mock(return_value=self.fake_network)
+        self.network.find_port = mock.Mock(return_value=self.fake_port)
+        self.network.find_router = mock.Mock(return_value=self.fake_router)
 
         # Get the command object to test
         self.cmd = floating_ip.ListFloatingIP(self.app, self.namespace)
@@ -267,10 +349,149 @@ class TestListFloatingIPNetwork(TestFloatingIPNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.ips.assert_called_once_with(**{})
+        self.network.ips.assert_called_once_with()
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
 
+    def test_floating_ip_list_network(self):
+        arglist = [
+            '--network', 'fake_network_id',
+        ]
+        verifylist = [
+            ('network', 'fake_network_id'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with(**{
+            'floating_network_id': 'fake_network_id',
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_floating_ip_list_port(self):
+        arglist = [
+            '--port', 'fake_port_id',
+        ]
+        verifylist = [
+            ('port', 'fake_port_id'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with(**{
+            'port_id': 'fake_port_id',
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_floating_ip_list_fixed_ip_address(self):
+        arglist = [
+            '--fixed-ip-address', self.floating_ips[0].fixed_ip_address,
+        ]
+        verifylist = [
+            ('fixed_ip_address', self.floating_ips[0].fixed_ip_address),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with(**{
+            'fixed_ip_address': self.floating_ips[0].fixed_ip_address,
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_floating_ip_list_long(self):
+        arglist = ['--long', ]
+        verifylist = [('long', True), ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with()
+        self.assertEqual(self.columns_long, columns)
+        self.assertEqual(self.data_long, list(data))
+
+    def test_floating_ip_list_status(self):
+        arglist = [
+            '--status', 'ACTIVE',
+            '--long',
+        ]
+        verifylist = [
+            ('status', 'ACTIVE'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with(**{
+            'status': 'ACTIVE',
+        })
+        self.assertEqual(self.columns_long, columns)
+        self.assertEqual(self.data_long, list(data))
+
+    def test_floating_ip_list_project(self):
+        project = identity_fakes_v3.FakeProject.create_one_project()
+        self.projects_mock.get.return_value = project
+        arglist = [
+            '--project', project.id,
+        ]
+        verifylist = [
+            ('project', project.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'tenant_id': project.id,
+                   'project_id': project.id, }
+
+        self.network.ips.assert_called_once_with(**filters)
+
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_floating_ip_list_project_domain(self):
+        project = identity_fakes_v3.FakeProject.create_one_project()
+        self.projects_mock.get.return_value = project
+        arglist = [
+            '--project', project.id,
+            '--project-domain', project.domain_id,
+        ]
+        verifylist = [
+            ('project', project.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'tenant_id': project.id,
+                   'project_id': project.id, }
+
+        self.network.ips.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
+    def test_floating_ip_list_router(self):
+        arglist = [
+            '--router', 'fake_router_id',
+            '--long',
+        ]
+        verifylist = [
+            ('router', 'fake_router_id'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.ips.assert_called_once_with(**{
+            'router_id': 'fake_router_id',
+        })
+        self.assertEqual(self.columns_long, columns)
+        self.assertEqual(self.data_long, list(data))
+
 
 class TestShowFloatingIPNetwork(TestFloatingIPNetwork):
 
